# ingdirect

# Description

Ce package permet de consulter très simplement ses comptes bancaires [ING Direct](https://www.ingdirect.fr/).

# Pré-requis

- Python 3
- TODO : à compléter

# Installation

TODO

# Utilisation

TODO
